==> tkvoice-1.0.tar.gz: tkvoice-1.0/tkvmodem.tcl <==
# tkvmodem.tcl --
#
#

if {![info exists tkVoice]} {
    error "This script should be run from within  \"tkvoice\"."
}

set w .tkvmodem
catch {destroy $w}
toplevel $w
wm title $w "tkVoice Modem Setup"
wm iconname $w "tkVoice Modem Setup"
positionWindow $w

# tkvoice setup image
frame $w.gif
pack $w.gif -side top -fill x

catch {image delete tkvoicemodem}
image create photo tkvoicemodem -file [file join $tkvoicedir/image/tkvoicemodem.gif]
label $w.gif.tkvoicemodem -image tkvoicemodem -bd 1 -relief sunken
label $w.gif.linux -image linux -bd 1 -relief sunken
label $w.gif.phone -image phone -bd 1 -relief sunken
label $w.gif.penguin -image penguin -bd 1 -relief sunken
 
pack $w.gif.phone -side left
pack $w.gif.tkvoicemodem -side left -expand 1 -fill x
pack $w.gif.linux -side right
pack $w.gif.penguin -side right

label $w.msg -font $font -wraplength 5i -justify left -text "These Options will be used when invoking PVF tools.\n\nChoose the type of Modem you are using.\nChoose the Compression Method for your modem.\n\nIf you need more help try \"pvftormd -L\" at a shell prompt."
pack $w.msg -side top

frame $w.buttons
pack $w.buttons -side bottom -fill x -pady 2m
button $w.buttons.save -text SAVE -command "savemodem; destroy $w"
button $w.buttons.cancel -text CANCEL -command "destroy $w"
pack $w.buttons.save $w.buttons.cancel -side left -expand 1

frame $w.left
frame $w.right
pack $w.left $w.right -side left -expand yes  -pady .5c -padx .5c

foreach i  { Digi Elsa ISDN4Linux Lucent MT_2834 MT_5634 Rockwell UMC US_Robotics V253modem ZyXEL_1496 ZyXEL_2864 ZyXEL_Omni56K }  {
    radiobutton $w.left.b$i -text "Modem Type $i" -variable MODEMTYPE \
	    -relief flat -value $i
    pack $w.left.b$i  -side top -pady 2 -anchor w
}

foreach x { 1 2 3 4 5 6 7 8 9 81 } {
    radiobutton $w.right.$x -text "Compression Method $x" -variable MODEMCOMP \
	    -relief flat -value $x
    pack $w.right.$x -side top -pady 2 -anchor w
}

==> tkvoice-1.1.tar.gz: tkvoice-1.1/tkvmodem.tcl <==
# tkvmodem.tcl --
#
#

if {![info exists tkVoice]} {
    error "This script should be run from within  \"tkvoice\"."
}

set w .tkvmodem
catch {destroy $w}
toplevel $w
wm title $w "tkVoice Modem Setup"
wm iconname $w "tkVoice Modem Setup"
wm iconbitmap $w @$tkvoicedir/image/icon
positionWindow $w

# tkvoice setup image
frame $w.gif
pack $w.gif -side top -fill x

catch {image delete tkvoicemodem}
image create photo tkvoicemodem -file [file join $tkvoicedir/image/tkvoicemodem.gif]
label $w.gif.tkvoicemodem -image tkvoicemodem -bd 1 -relief sunken
label $w.gif.linux -image linux -bd 1 -relief sunken
label $w.gif.phone -image phone -bd 1 -relief sunken
label $w.gif.penguin -image penguin -bd 1 -relief sunken
 
pack $w.gif.phone -side left
pack $w.gif.tkvoicemodem -side left -expand 1 -fill x
pack $w.gif.linux -side right
pack $w.gif.penguin -side right

label $w.msg -font $font -wraplength 5i -justify left -text "These Options will be used when invoking PVF tools.\n\nChoose the \"pvfspeed\" number of samples\nper second for your modem."
pack $w.msg -side top

frame $w.buttons
pack $w.buttons -side bottom -fill x -pady 2m
button $w.buttons.save -text SAVE -command "savemodem; destroy $w"
button $w.buttons.cancel -text CANCEL -command "destroy $w"
pack $w.buttons.save $w.buttons.cancel -side left -expand 1

frame $w.top
pack $w.top -side top -expand yes -pady .1c -padx .5c
foreach x { 7200 8000 9600 } {
    radiobutton $w.top.$x -text "$x Samples\/sec" -variable pvfsamples \
                -relief flat -value $x -command "set custpvfs 0"
    pack $w.top.$x -side top -pady 2 -anchor w
}
radiobutton $w.top.other -text "Other" -variable custpvfs -relief flat -value 1
entry $w.top.entry -relief sunken -width 5 -textvariable pvfsamples
pack $w.top.other -side left  -pady 2
pack $w.top.entry -side right -pady 2

label $w.msglower -font $font -wraplength 5i -justify left -text "Choose the type of Modem you are using.\nChoose the Compression Method for your modem."
pack $w.msglower -side top

frame $w.left
frame $w.right
pack $w.left $w.right -side left -expand yes  -pady .1c -padx .5c

foreach i  { Digi Elsa ISDN4Linux Lucent MT_2834 MT_5634 Rockwell UMC US_Robotics V253modem ZyXEL_1496 ZyXEL_2864 ZyXEL_Omni56K }  {
    radiobutton $w.left.b$i -text "Modem Type $i" -variable MODEMTYPE \
	    -relief flat -value $i
    pack $w.left.b$i  -side top -pady 2 -anchor w
}

foreach x { 1 2 3 4 5 6 7 8 9 81 } {
    radiobutton $w.right.$x -text "Compression Method $x" -variable MODEMCOMP \
	    -relief flat -value $x
    pack $w.right.$x -side top -pady 2 -anchor w
}
